Monty Python's Flying Circus: Just the Words - Episode 35

# Episode Thirty-five

Bomb on plane
A naked man
Ten seconds of sex
Housing project built by characters from nineteenth-century English literature
M1 interchange built by characters from 'Paradise Lost'
Mystico and Janet - flats built by hypnosis
'Mortuary Hour'
The Olympic hide-and-seek final
The Cheap-Laughs
Bull-fighting
The British Well-Basically Club
Prices on the planet Algon

Colour code: John Cleese - Michael Palin - Eric Idle - Graham Chapman - Terry Jones - Terry Gilliam - Carol Cleveland

| Fade up on two pilots in the cockpit of an aeroplane. A stewardess is there too. After a moment or two the first pilot makes an announcement.
First Pilot | This is Captain MacPherson welcoming you aboard East Scottish Airways. You'll have had your tea. Our destination is Glasgow. There is no need to panic.
| The door of the cockpit opens and Mr Badger comes in.
Badger | There's a bomb on board this plane, and I'll tell you where it is for a thousand pounds.
Second Pilot | I don't believe you.
Badger | If you don't tell me where the bomb is... if I don't give you the money... Unless you give me the bomb...
Stewardess | The money.
Badger | The money, thank you, pretty lady... the bomb will explode killing everybody.
Second Pilot | Including you.
Badger | I'll tell you where it is for a pound.
Second Pilot | Here's a pound.
Badger | I don't want Scottish money. They've got the numbers. It can be traced.
Second Pilot | One English pound. Now where's the bomb?
Badger | I can't remember.
Second Pilot | You've forgotten.
Badger | Aye, you'd better have your pound back. Oh... (rubs it) fingerprints.
First Pilot | Now where's the bomb?
Badger | Ah, wait a tic, wait a tic. (closes eyes and thinks) Er, my first is in Glasgow but not in Spain, my second is in steamer but not in train, my whole is in the luggage compartment on the plane... (opens eyes) I'll tell you where the bomb is for a pound.
Second Pilot | It's in the luggage compartment.
Badger | Right. Here's your pound..
| Enter a man with headphones.
Headphones | Is this character giving you any trouble?
First Pilot | He's just ruined this sketch.
Second Pilot | Yes, absolutely.
Headphones | Let's go on to the next one.
Badger | Wait a tic, wait a tic. No. I won't ruin your sketch for a pound.
Second Pilot | No, no.
Badger | 75p.
Headphones | Next item. (they start to leave)
| The nude organist is seated at his organ in the open air, with a lovely scarlet dressing-gown draped round his shoulders. It says on it 'Noel Coward' which is crossed out and 'Nude Organist' written underneath. He is holding forth to a journalist with a notepad who is nodding and interviewing him. Someone else holds a small tape recorder. Make-up ladies are adding the finishing touches. They bring him a mirror while he talks. Someone is taking photos of him, perhaps with flashbulbs.
Nude Man | Well I see my role in it as, er, how can I put it best - the nude man - as sort of symbolizing the two separate strands of existence, the essential nudity of man...
| They realize that they are on camera. They remove the man's robe and clear the set. He grins at the camera and plays his chords. Cut to the announcer. He is sitting at his desk in the middle of a field but he is talking earnestly to a trendy girl reporter.
Announcer | It's an interesting question. Personally I rather adhere to the Bergsonian idea of laughter as a social sanction against inflexible behaviour but... excuse me a moment... And now...
It's Man | It's...
| Animated titles.
Voice Over | (and CAPTION:) 'AND NOW THE TEN SECONDS OF SEX'
| Black screen and the sound of a ticking clock for ten seconds.
Voice Over | (and CAPTION:) 'ALL RIGHT, YOU CAN STOP NOW'
| Cut to a little palm court set. A man seated.
Man in Tails | Well, we'll be continuing with 'Monty Python's Flying Circus' in just a moment (consults his watch) fr...o...m nnnnnnnnnnnn...now.
| Cut to a building site. The camera pans over it.
Voice Over | This new housing development in Bristol is one of the most interesting in the country. It's using a variety of new techniques: shock-proof curtain-walling, a central high voltage, self-generated electricity source, and extruded acrylic fiberglass fitments. It's also the first major housing project in Britain to be built entirely by characters from nineteenth-century English literature.
| By, this time the pan has come to rest on a section of the site where various nineteenth-century literary figures are at work round a cement mixer: two ladies in crinolines, Bob Cratchett on his father's back, Heathcliff and Catherine throwing bricks to each other with smouldering passion, Nelson, Mr Beadle as foreman. Cut to the interior of a half-finished concrete shell. A little girl is working on top of a ladder.
Voice Over | Here Little Nell, from Dickens's 'Old Curiosity Shop' fits new nylon syphons into the asbestos-lined ceilings ... (shot of complicated electrical wiring in some impressive electrical installation) But it's the electrical system which has attracted the most attention. (cut to Arthur Huntingdon studying a plan; he has a builder's safety helmet on) Arthur Huntingdon, who Helen Graham married as a young girl, and whose shameless conduct eventually drove her back to her brother Lawrence, in Anne Brontë's 'The Tenant of Wildfell Hall' describes why it's unique.
Huntingdon | Because sir, it is self-generating. Because we have harnessed here in this box the very forces of life itself. The very forces that will send Helen running back to beg forgiveness!
| Cut to a close up of big pre-fabricated concrete slabs being hoisted into the air by a crane and start to pull out, as the commentator speaks, to reveal a crowd of nineteenth-centuty farmhands working on them.
Voice Over | The on-site building techniques involve the construction of twelve-foot walling blocks by a crowd of farmhands from 'Tess of the D'Urbervilles' supervised by the genial landlady, Mrs Jupp, from Samuel Butler's 'Way of All Flesh'.
| Pan to reveal Mrs Jupp with a clipboard. Cut to voice over narrator in vision with a stick-mike, in front of an impressive piece of motorway interchange building. Behind him and working on the site are six angels, three devils, and Adam and Eve.
Narrator | In contrast to the site in Bristol, it's progress here on Britain's first eighteen-level motorway interchange being built by characters from Milton's 'Paradise Lost'...
| He turns and we zoom past him into the angels etc.
Narrator | (voice over) What went wrong here?
| Cut to a foreman in a donkey jacket and helmet.
Foreman | Well, no one really got on. Satan didn't get on with Eve ... er... Archangel Gabriel didn't get on with Satan... nobody got on with the Serpent, so now they have to work a rota: forces of good from ten till three, forces of evil three to six.
| The camera tracks through a high-rise development area.
Voice Over | But even more modern building techniques are being used on an expanding new town site near Peterborough; here the Amazing Mystico and Janet can put up a block of flats by hypnosis in under a minute.
| Mystico removes his cloak, gloves and top hat and hands them to Janet, who curtsies. He then makes several passes. Cut to stock film of flats falling down reversed so that they leap up. Cut back to Mystico and Janet. She hands him back his things as they make their way to their car, a little Austin 30.
Voice Over | The local Council here have over fifty hypnosis-induced twenty-five story blocks, put up by El Mystico and Janet. I asked Mr Ken Verybigliar the advantages of hypnosis compared to other building methods.
| Cut to a man in a drab suit.
| SUPERIMPOSED CAPTION: 'MR K. V. B. LIAR'
Mr Verybigliar | Well there is a considerable financial advantage in using the services of El Mystico. A block, like Mystico Point here, (indicating a high-rise block behind him) would normally cost in the region of one-and-a-half million pounds. This was put up for five pounds and thirty bob for Janet.
Voice Over | But the obvious question is are they safe?
| Cut to an architect's office. The architect at his desk. Behind him on the wall are framed photos of various collapsed buildings. He is a well-dressed authoritative person.
| SUPERIMPOSED CAPTION: 'MR CLEMENT ONAN, ARCHITECT TO THE COUNCIL'
Architect | Of course they're safe. There's absolutely no doubt about that. They are as strong, solid and as safe as any other building method in this country provided of course people believe in them.
| Cut to a council flat. On the wall there is a picture of Mystico.
Tenant | Yes, we received a note from the Council saying that if we ceased to believe in this building it would fall down.
Voice Over | You don't mind living in a figment of another man's imagination?
Tenant | No, it's much better than where we used to live.
Voice Over | Where did you used to live?
Tenant | We had an eighteen-roomed villa overlooking Nice.
Voice Over | Really, that sounds much better.
Tenant | Oh yes - yes you're right.
| Cut to stock shot of block falling down in slow motion. Cut back to tenant and wife inside. Camera shaking and on the tilt.
Tenant | No, no, no, of course not.
| Cut to stock film again. The building rights itself. Cut back to interior again. Camera slightly on tilt. They are holding bits of crockery etc.
Tenant | Phew, that was close.
| Cut to tracking shot from back of camera car again. This time El Mystico striding through the towering blocks, his cloak swirling behind him.
Voice Over | But the construction of these vast new housing developments, providing homes for many thousands of people, is not the only project to which he has applied his many talents. He also has an Infallible Pools Method, a School of Spanish Dancing and a Car Hire Service. (cut to Mystico at wheel of his little Austin 30, his amazing eyes riveted on the road ahead; Janet occasiona1ly tactfully guides the steering wheel) What is the driving force behind a man of such restless energies, and boundless vision? Here as with so many great men of history, the answer lies in a woman... (the camera pans over on to Janet and starts to zoom in on her as she watches the road ahead; cut to a nineteenth-century engraving of Shakespeare's Antony and Cleopatra) As Antony has his Cleopatra... (cut to picture of Napoleon and Josephine) as Napoleon has his Josephine... (cut to Janet lying on a bed in a negligie in a rather seedy hotel) So Mystico has his Janet.
| Mystico leaps from top of the wardrobe on to the bed with a lusty yell. Cut to montage of black and white photos of Janet in various stage poses: three poses against black drapes; one against a building; one posed outside a terrace house with notice reading 'School of Spanish Dancing - Dentures Repaired'.
Voice Over | Yes. Janet ... a quiet, shy girl. An honours graduate from Harvard University, American junior sprint record holder, ex-world skating champion, Nobel Prize winner, architect, novelist and surgeon. The girl who helped crack the Oppenheimer spy ring in 1947. She gave vital evidence to the Senate Narcotics Commission in 1958. She also helped to convict the woman at the chemist's in 1961, and a year later (cut to Janet shaking hands with a police commissioner) she gave police information which led to the arrest of her postman. In October of that same year (cut to photo of Janet with a judge and a policeman standing on either side of her smiling at the camera) she secured the conviction of her gardener for bigamy and three months later personally led the police swoop (cut to Janet in a street with goggles of policemen clustering round her grinning at the camera and two people obviously naked with blankets thrown over them) on the couple next door. In 1967 she became suspicious of the man at the garage (cut to a photo of a petrol attendant filling a car) and it was her dogged perseverance and relentless enquiries (another rather fuzzy photo of the man at the garage peering through the window of cash kiosk) that two years later finally secured his conviction for not having a licence for his car radio. (final photo of five police, Janet and the man from the garage in handcuffs all posing for the camera) He was hanged at Leeds a year later (cut to Janet posing outside a prison) despite the abolition of capital punishment and the public outcry. Also in Leeds that year, a local butcher was hanged (cut to a blurred family snap of a butcher in an apron with a knife) for defaulting on mortgage repayments, and a Mr Jarvis (photo) was electrocuted for shouting in the corridor.
| Cut to Superintendent Harry 'Boot-in' Swalk'
| SUPERIMPOSED CAPTION: 'SUPERINTENDENT HARRY "BOOT-IN" SWALK'
Swalk | We admit that there have been outbreaks of hanging recently, but the police are trying to keep the situatuon under control. (his personal two-way radio is making rather a noise) You must remember the courts are very busy at the moment and the odd death sentence is bound to slip through. (claps his hand over the radio to little avail) Electrocutions are another big worry. But we hope that guillotining has been eradicated from the urban areas. and garrotting is confined almost entirely to Luton. So if you have a friend in prison or under the sentence of death, be sure to let us know at this address.
Voice Over | (and CAPTION:) 'THE POLICE FORCE, "SUNNYVIEW", YEOVIL, SOMERSET'
| Cut to a mortuary. Various trolleys lie about with corpses covered by sheets. Two workers are sitting at a low make-shift table with cups of tea and a transistor radio, shelling eggs and dropping them in a pickling jar.
First Radio Voice | ... and Premier Chou En Lai, who called it 'a major breakthrough'. Twelve men were accidentally hanged at Whitby Assizes this afternoon whilst considering their verdict. This is one of the worst miscarriages of justice in Britain since Tuesday. (music)
DJ Voice | Well it's thirteen minutes to the hour of nine-nine-nine, here on wonderful Radio One-One-One! So if you're still lying in your big big bed, now is the time to get up out of it! We've got another thirteen hours of tip-top sounds here on Wonderful Radio One! (brief funny noises) Sorry about that ... So unless you have brain cells, or have completed the process of evolution, there's a wonderful day ahead!
Battersby | (switching the radio off) It must be on Radio Four. (he gets another radio out from underneath the table) Radio Two. (he gets another radio out) ... Three ... (he opens the top of the third radio and gets out a fourth; he switches it on)
Second Radio Voice | It's 9 o'clock and time for 'Mortuary Hour'. An hour of talks, tunes and downright tomfoolery for all those who work in mortuaries, introduced as usual by Shirley Bassey. (sinister chords).
Shirley | Well, we're going to kick straight off this week with our Mortuary Quiz, so have your pens and pencils ready.
| A door at the back of the mortuary opens and Mr Wang, an official of the Department of Stiffs, enters. He wears an undertaker's suit and top hat plus a long blond wig.
Wang | Turn that radio off and look lively!
Battersby | Oh, it's 'Mortuary Quiz', Mr Wang...
Wang | Don't argue, Battersby.
| We hear voices off. Officials at the door spring to attention. Enter a mayor with a chain round his neck, and an elderly peer of the realm who is standing on a small platform, pushed by an attendant.
Mayor | ... This is our mortuary in here, Your Grace ...
Peer | I see, I see, I ... er ... I ... er ... I ... er ... I ... I can't think of anything to say about it.
Mayor | Well, we're very proud of it here, sir. It's one of the most up to date in the country.
Peer | I see... yes... yes ... now... um... what... what... ah... ah... what is it? .... is it a power station?
Mayor | No, Your Grace, it's a mortuary.
Peer | I see ... I see ... good ... good ... good, good, good...
Mayor | But it has one of the most advanced thermostat control systems in the country, and it has computer-controlled storage facilities.
Peer | I see, I see ... I ... er... er... er... er ... I ... er ... I'm a good little doggie.
Mayor | I'm sorry, Your Grace?
Peer | I'm a good little dog.
Attendant | Oh dear...
Mayor | Perhaps we should postpone the visit?
Attendant | No, no, no - you see it's just that his brain is so tiny that the slightest movement can dislodge it (starts to slap the duke's head from side to side gently but firmly) Your Grace ... Oh dear... it's rather like one of those games you play where you have to get the ball into the hole ... That's it.
Peer | Ah! Now then, excellent, excellent, excellent, excellent. Now then ... ah ... what happens when the steel is poured into the ingots?
Mayor | (ushering everyone out) Perhaps we should go and have a look at the new showers?
Peer | Yes... yes ... yes ... yes... yes rather jolly good... jolly good .. jolly good ... jolly good ... no fear...
| They leave. Battersby turns the radio on again.
Radio Voice | Well the answers were as follows: 1) the left hand, 2) no, 3) normal, 4) yes it has, in 1963 when a bird got caught in the mechanism. How did you get on?
| Two men behind him push in a trolley with sheet-covered corpses on it.
Wang | Turn that thing off!
Battersby | Oh! It's 'Mortuary Dance Time', Mr Wang!
Wang | Never mind that, Battersby, this is the big one. I've just had Whitby Police on the phone with twelve hangees...
Battersby | Oh yes, I just heard about that on the radios ...
Wang | No, these are twelve different ones ... so shtoom.
| Battersby and friend gather round the body. Wang joins them. They start to work away busily and eficiently on the corpse. We suddenly become aware that Badger is standing with them around the body.
Badger | I'll not interrupt this sketch for a pound.
Wang | What?
Badger | For one pound I'll leave this sketch totally uninterrupted.
Wang | What?
Badger | Fifty pence ... I'm prepared to negotiate a forty-pence deal. (an eye peers out from under the sheet on the corpse they are working on) For 35p I won't interrupt any of the next three items.
| The corpse is now sitting up waiting to see what happens. Another corpse sits up as they continue arguing. The sheet is pushed back on another trolley revealing a boy and girl on the same stretcher. They light cigarettes.
Wang | No, no, it's no good...
Badger | 25p.
Wang | No.
Badger | 10p and a kiss.
| ANIMATION: with Gilliam's hands in shot.
Terry Gilliam | (voice over) You see, it's very simple - I just take these cut-out figures and by putting them together... oh, you mean we're on?... (Gilliam's head appears briefly) Sorry.
| The animated sketch starts. Then cut to Trafalgar Square. The Olympic symbol is superimposed briefly.
| SUPERIMPOSED CAPTION: 'FINAL OF THE HIDE-AND-SEEK SECOND LEG'
| Zoom in on commentator and the two finalists, forty-year-old men limbering up in shorts and singlets.
Commentator | Hello, good afternoon and welcome to the second leg of the Olympic final of the men's Hide-and-Seek here in the heart of Britain's London. We'll be starting in just a couple of moments from now, and there you can see the two competitors Francisco Huron the Paraguayan, who in this leg is the seeker (we see Francisco Huron darting about, looking behind things) and there's the man he'll be looking for ... (we see Don Roberts practising hiding) our own Don Roberts from Hinckley in Leicestershire who, his trainer tells me, is at the height of his self-secreting form. And now in the first leg, which ended on Wednesday, Don succeeded in finding the Paraguayan in the new world record time of 11 years, 2 months, 26 days, 9 hours, 3 minutes, 27.4 seconds, in a sweetshop in Kilmarnock. And now they're under starter's orders.
| We see Don Roberts and Francisco Huron standing side by side, poised, looking nervous.
Starter | (voice over) On your marks... get set...
| The starter fires his pistol. Francisco Huron immediately puts his hands over eyes and starts counting.
Francisco | Uno, dos, tres, quattro, cinque, seis, siete, ocho, nueve, diez ...
| Meanwhile Don Roberts hails a cab. He gets in and it drives off.
Francisco | ... trientay dos, trientay tres, trientay quattro...
| SUPERIMPOSED CAPTION: '32, 33, 34'
Commentator | Well Don's off to a really great start there. Remember the Paraguayan has got 11 years, 2 months, 26 days, 9 hours... (cut to taxi on the way to London airport) 3 minutes, 27.4 seconds to beat.
| Cut back to Francisco still counting.
| SUPERIMPOSED CAPTION: '998, 999, 1000'
Francisco | Neuvecian no nuevetay ocho, nuevecientas nuevente ye nueve, mil. (Francisco takes his hands from his eyes and shouts) Coming!
| He starts looking around the immediate locality suspiciously. We see a plane landing. There is a sign saying 'Benvenuto a Sardinia'. Cut to Don on a bicycle. Then running up a hill. Then going into castle. Running along corridors and eventualy pausing, looking around agitatedly, and then hiding behind a pillar. Occasionally he looks out nervously. Then cut to Francisco looking in shops in the Tottenham Court Road. Cut to studio 'Sportsview' desk with a Frank Bough man at it.
Frank Bough | Well, we'll be taking you back there as soon as there are any developments.
| CAPTION: 'SIX YEARS LATER'
| Cut back to desk. Frank Bough looks older.
Frank Bough | We've just heard that something is happening in the Hide-and-Seek final, so let's go straight over there.
| Cut to film of Francisco Huron. He is wandering around looking for Don Roberts in a beach setting. The commentator is some way from him. He speaks quietly into a microphone.
Commentator | Hello again, and welcome to Madagascar, where Francisco Huron is seeking Don Roberts. And I've just been told that he has been told that he has been unofficially described as 'cold'. Ah, wait a minute. (in the distance Francisco Huron consults with an official; the commentator moves out of shot briefly, then returns) I've just been told that Huron has requested a plane ticket for Budapest! So he's definitely getting warmer. So we'll be back again in just a few years.
| Cut to Frank Bough looking older. He is covered with cobwebs.
Frank Bough | Really beginning to hot up now.
| CAPTION: 'FIVE YEARS, TWO MONTBS AND TWENTY-SIX DAYS LATER'
| Cut to a Portuguese-looking setting. Francisco Huron looking round desperately and glancing at his watch.
Commentator | So here we are on the very last day of this fantastic final. Huron now has less than twelve hours left to find British ace Don Roberts. Early this morning he finished combing the outskirts of Lisbon and now he seems to have staked everything on one final desperate seek here in the Tagus valley. But Roberts is over fifteen hundred miles away, and it's beginning to look all over, bar the shouting. The sands of time are running out for this delving dago, this savior of seek, perspicacious Paraguayan. He's still desperately cold and it's beginning to look like another gold for Britain.
| The camera shows Huron creeping up on a dustbin. He pauses, snatches off the lid and looks inside. He turns away disappointed then does double take and looks back into the bin. He pulls out a sardine tin with the word 'Sardines' very obvious. Shot of Huron's reaction as he suddenly gets a tremendous idea. He snaps his fingers and hails a taxi and gets in. Cut to plane landing. Same sign as before 'Benvenuto a Sardinia'. Francisco cycles past. Cut to him discarding the bike and running up the hill straight into the castle. He runs along corridors into the right room, up to the pillar and finds Don Roberts skulking behind. They both look very tense as they await the official result, then react in fury and frustration when it is announced by a blazered offical.
Official | The official result of the World Hide-and-Seek, Mr Don Roberts from Hinckley, Leicestershire, 11 years, 2 months, 26 days, 9 hours, 3 minutes, 27 seconds. Mr Francisco Huron, Paraguay, 11 years, a months, 26 days, 9 hours, 3 minutes, 27 seconds. The result - a tie.
Voice Over | A tie! Well what a fantastic result. Well the replay will start tomorrow at 7.30 a.m.
| As they stand there the camera pans off them to a window and then zooms through the window to reveal a beach where there is a Redcoat.
Redcoat | Well hello again .... nice to be back ... glad to see the series has been doing well. Well now, sorry about Mon-trerx.
| At this point two men run past in the background carrying a donkey. A third runs behind carrying a sign saying 'Donkey Rides' and winking and pointing at the donkey, they run out of picture.
Redcoat | That was a little item entitled Hide-and-Seek - very anarchic, very effective, not quite my cup of tea, but very nice for the younger people. Well, the next item the boys have put together takes place in a sitting room. Sorry it's just a sitting room, but the bank account's a bit low after the appallingly expensive production of 'Clochmerle'...
| He is hit by Mr Robinson with a chicken. Robinson walks away and we follow him as he passes Badger in the foreground.
Badger | This is a totally free interruption and no money has exchanged hands whatever.
| The camera doesn't pause at all on Badger and we continue panning with Robinson until he reaches the knight in amour. He hands the chicken to the knight. He walks away from knight and into the distance. Mix through to a modern sitting room. Mrs Robinson is eating alone at the table looking at the clock.
Mr Robinson | Sorry about that, darling... (he sits)
| She serves him some vegetables. He unfolds his napkin.
Mrs Robinson | Gravy?
Mr Robinson | Yes please, dear.
| They sit and eat in silence. Suddenly the doorbell rings.
Mrs Robinson | Oh dear, that'll be the Cheap-Laughs from next door.
| Various different doorbell sounds and chimes. Mr Robinson goes to the front door, and opens it. Standing outside are Mr and Mrs Cheap-Laugh. He is wearing a big floppy comedian's suit and a big bow tie and fright wig. She is a Mrs Equator sort of lady, with an enormous hairstyle, and dressed in very bad taste.
Mr Robinson | Come in.
Mr Cheap-Laugh | No! Just breathing heavily!
| He and his wife roar with laughter. As he comes in he slips and falls on the mat. His wife puts a custard pie in his face. More roars of laughter.
Mrs Cheap-Laugh | Oh we just dropped in.
Mr Robinson | Would you like to come through...
| We mix through to the exterior of a house at night. Shrieks of laughter, crushes of crockery. The two men with the donkey run past in road, the third man behind pointing to the sign.
| SUPERIMPOSED CAPTION: 'ONE EVENING WITH THE CHEAP-LAUGHS LATER'
| The light comes on in hall. Cut to them in the hall at the front door.
Mr Cheap-Laugh | Well goodnight and give us a kiss. (kisses Mrs Robinson)
Mrs Cheap-Laugh | Oh thank you very much for a very nice evening.
Mr Cheap-Laugh | After you, dear.
| He trips her up and she falls out into the darkness. We hear her shriek with laughter. Mr Cheap-Laugh drops his trousers, makes lavatory chain pulling sign and noise and hurls himself out after wife and disappears into the darkness. More laughter. The host shuts the door. They heave a sigh of relief and go back into the sitting room. The crockery on the table is all smashed in a heap on the floor with the table cloth. The standard lamp is broken in half. There are large splodges of food and wine splashes on the walls. Some glasses and a moustache are drawn on the Tretchikoff picture of the Chinese girl. Mrs Robinson flops down on the sofa. There is a farting cushion. She removes it, irritated.
Mrs Robinson | Oh honestly dear, why do we always have to buy everything just because the Cheap-Laughs have one?
| He goes over to the wall cupboard for drinks. A bucket of whitewash is balanced on the half-open door. He opens the cupboard and the bucket of whitewash falls on him. Cut briefly to Mr Badger.
Badger | This is not an interruption at all.
| Cut back to Mr Robinson. He pours himself a drink, without reacting to the whitewash.
Mr Robinson | It's just neighbourliness dear, that's all...
Mrs Robinson | I think we should try and lead our own lives from now on.
| She opens a sewing box and a boxing glove on a spring comes out and hits her on the chin.
Mr Robinson | Can't you be serious for one moment?
| He sits on the pouffe. The sixteen-ton weight falls on him. Cut to the exterior of the house. The lights go off downstairs and upstairs. The two men run past carrying a pantomime goose.
| SUPERIMPOSED CAPTION: 'LATER THAT NIGHT'
| Cut to a darkened bedroom. Mr and Mrs Robinson are in a double bed, talking.
Mr Robinson | I'm sorry I was cross earlier.
Mrs Robinson | Oh that's all right, dear. It's just that I get so sick of always having to be like the Cheap-Laughs.
Mr Robinson | Well yes, from now on we'll be like ourselves.
Mrs Robinson | Oh Roger...
Mr Robinson | Oh Beatrice.
| The bed springs up and folds into the back wall of the bedroom. On the underneath of the bed is a presenter on a chair. The underneath of the bed also consists of a flat as for current affairs-type programme, with 'Probe' written above narrator.
Presenter | Many people in this country are becoming increasingly worried about bull-fighting. They say it's not only cruel, vicious and immoral, but also blatantly unfair. The bull is heavy, violent, abusive and aggressive with four legs and great sharp teeth, whereas the bull-fighter is only a small, greasy Spaniard. Given this basic inequality what can be done to make bull-fighting safer? We asked Brigadier Arthur Farquar-Smith, Chairman of the British Well-Basically Club.
| Cut to a brigadier.
Brigadier | Well, basically it's quite apparent that these little dago chappies have got it all wrong. They prance round the bull like a lot of bally night club dancers looking like the Younger Generation or a less smooth version of the Lionel Blair Troupe, (getting rather camp) with much of the staccato rhythms of the Irving Davies Dancers at the height of their success. In recent years Pan's People have often recaptured a lyricism ... (a huge hammer strikes him on the head; he becomes butch again) and what we must do now is to use devices like radar to locate the bull and SAM missiles fired from underground silos, to knock the bull over. Then I would send in Scottish boys with air cover to provide a diversion for the bull, whilst the navy came in round the back and finished him off. That to me would be bull-fighting and not this pansy kind of lyrical, (getting camp) evocative movement which George Balanchine and Martha Graham in the States and our very own Sadler's Wells ... (the hammer strikes him on the head again) Troops could also be used in an auxiliary role in international chess, where... (the lights go off) What? ... oh...
Badger | (voice over) I'll put the lights on again for a pound.
| Cut to an animated sketch, and then to a strange moonlike landscape. Eerie science-fiction music plays in the background.
Voice Over | This is the planet Algon, fifth world in the system of Aldebaran, the Red Giant in the constellation of Sagittarius. Here an ordinary cup of drinking chocolate costs four million pounds, an immersion heater for the hot-water tank costs over six billion pounds, and a pair of split-crotch panties would be almost unobtainable. (cut to a budget-day-type graphic, with a picture of the product and the price alongside) A simple rear window de-misting device for an 1100 costs eight thousand million billion pounds and a new element for an electric kettle like this (picture of electric kettle) would cost as much as the entire gross national product of the United States of America from 1770 to the year 2000, (graphic of American GNP) and even then they wouldn't be able to afford the small fixing ring which attaches it to the kettle. (graphic of an electric kettle showing all the separate pieces detatched from each other, arrow points to the fixing ring)
| Cut to James M'Burke sitting at a desk. 'Algon I' motifs everywhere. Another expert stands by a model of the planet, and there is a panel of experts at a long desk who are all obviously dummies. Everyone has one of those single earphones.
M'Burke | Well, our computers have been working all day to analyse the dramatic information that's come in from this first ever intergalactic probe, Algon I ... (suddenly very excited as he hears something over his earphone) ... and we're just getting an interesting development now, which is that attachments for rotary mowers - that is mowers that have a central circular blade - are... relatively inexpensive! Still in the region of nine to ten million pounds, but it does seem to indicate that Algon might be a very good planet for those with larger gardens ... or perhaps even an orchard that's been left for two years, needs some heavy work, some weeding... (very, indistinct pictures start to come through on the screen behind him) But we're now getting some live pictures through from Algon! Harry - Perhaps you could talk us through them.
| Cut into pictures from Algon.
| SUPERIMPOSED CAPTION: 'LIVE FROM ALGON'
| Very fuzzy pictures of the Algon landscape. Panning and tracking shots hand held.
Harry | (voice over) Very little evidence of shopping facilities here .. there don't seem to be any large supermarkets. There may be some on-the-corner grocery stores behind those rocks, but it's difficult to tell from this angle. It does seem to suggest that most of the shopping here is by direct mail.
| SUPERIMPOSED TELEPRINTER CAPTION: 'DIGESTIVE BISCUITS; £8,OOO,OOO PER PACKET'
| Cut to James M'Burke.
M'Burke | Of course the big question that everyone's asking here is, what about those split-crotch parities? Are they going to be unobtainable throughout the Universe or merely on Algon itself? Professor?
| Cut to a professor sitting beside a contour model of an area of Algon. It has a little model of the probe marking where it has landed.
| SUPERIMPOSED CAPTION: 'PROFESSOR HERMAN KHAN, DIRECTOR OF THE INSTITUTE OF SPLIT-CROTCH PANTIES'
Professor | We must remember that Algon is over 75,000 miles wide. The probes come down to this area here and we're really only getting signals from a radius of only thirty or forty miles around the probe. Split-crotch panties, or indeed any items of what we scientists call, 'Sexy Underwear' or 'Erotic Lingerie' may be much more plentiful on other parts of the planet.
| Camera pans to include M'Burke.
M'Burke | Professor, you were responsible for finding Scanty-Panties and Golden Goddess High-Lift Bras on planets which were never thought able to sustain life, and now that man has discovered a new galaxy do you think we're going to see underwear become even naughtier?
Professor | Oh naughtier and naughtier.
| SUPERIMPOSED TELEPRINTER CAPTION: 'NO BANANAS ON ALGON'
M'Burke | Well so much for that ... But of course, the probe itself has excited a great deal of interest... for it contains uranium-based dual transmission cells entirely re-charged by solar radiation, which can take off a bra and panties in less than fifteen seconds. It is, of course, the first piece of space hardware to be specially designed to undress ladies, and so there are bound to be some teething troubles ... such as how to cope with the combination of elastic-sided boots and tights.
| He produces the bottom half of a tailor's dummy wearing boots and tights with panties over the tights halfway down. On the screen behind, more dim indecipherable TV pictures from Algon.
M'Burke | But I think we're getting some pictures now from Algon itself, and it looks as though ... yes! The satellite has found a bird! The probe has struck crumpet and she looks pretty good too! Professor?
Professor | Ja - she's a real honey!
| All we see on the screen is a blurred female figure.
M'Burke | Well the pictures are a bit sporadic... I think probably... the solar radiation during the long journey to Algon... (the screen goes blank) Hoy! Look! Oh dear, I'm sorry we've lost contact. We'll try and re-establish contact with Algon...
| Cut to presenter's-type chair. Mr Badger appears at side of screen.
Badger | Hello... The BBC have offered me the sum of forty pence to read the credits of this show. (sits) Personally I thought they should have held out for the full seventy-five, but the BBC have explained to me about their financial difficulties and ... er ... I decided to accept the reduced offer... so ... the show was conceived, written and performed by... the usual lot... (the signature tune is heard) Also appearing were Carol Cleveland, Marie Anderson, Mrs Idle, Make-up - Madelaine Gaffney, Costume - Hazel Pethig, Animations by Terry Gilliam, Visual Effects Designer - Bernard Wilkie, Graphics - Bob Blagden, Film Cameraman - Alan Featherstone, Film Editor - Ray Millichope, Sound - Richard Chubb, Lighting - Bill Bailey, Designer - Bob Berk, Produced by Ian MacNaughton for 92p and a bottle of Bells whisky ... it was a BBC colour production. That's just it. I'd like to say if there are any BBC producers looking in who need people to read the credits for them, I would personally...
| The camera pulls out to reveal the sixteen-ton weight poised above him. As the picture fades the weight falls on him.